% Lausanne, 9/1/2017
% -------------------------------------------------------------------
% demoSWMTextureAnalysis2D.m
% 
% Demo script for SWM texture analysis
% -------------------------------------------------------------------
%
% Adrien Depeursinge, adrien.depeursinge@epfl.ch
% EPFL, Biomedical Imaging Group (BIG), Lausanne, Switzerland
% HES-SO Valais, MedGIFT, Institute of Information Systems, Sierre, Switzerland
% -------------------------------------------------------------------
%
% REFERENCES:
% [1] A. Depeursinge, Z. Puspoki, J.P. Ward, M. Unser,
%       "Steerable Wavelet Machines (SWM): Learning Moving Frames for
%       Texture Classification", in press.
%
% [2] M. Unser and N. Chenouard, "A Unifying Parametric Framework for 2D Steerable
%       Wavelet Transforms", SIAM J. Imaging Sci., vol. 6., pp 102-135, 2013.
%
% -------------------------------------------------------------------

clearvars;close all;clc;

% Create toy image
imageSize = 128;
[X,Y] = meshgrid(1:imageSize,1:imageSize);
I = sin(X/(imageSize/96))+sin(Y/(imageSize/96))+rand(imageSize);
subplot(1,2,1); imshow(I,[]); title('texture');

% parameters for texture analysis
harmonicsVector = 0:2                                % number of circular harmonics
num_scales = 4;                                      % number of scales: number of iterations of the isotropic wavelet transform
pyramid = 0;                                         % 1: decimated, 0: undecimated wavelet transform
align = 1;                                           % 0: no steering, >1: moving frames built from scale=align
complexType = 'concatenated';                        % 'abs' is recommended if align = 0. 'concatenated' should be used otherwise
cropSupport = 1;                                     % crop the mask based on the spatial support of the wavelet to avoid the influence of surrounding object

% extract circular harmonic wavelet (CHW) coefficients
[Qu, angleMap]= SWMtextureAnalysis(I,harmonicsVector,num_scales,pyramid,align);

% texture features: compute mean of the abs of the CHW within an image region defined by a binary mask
mask = zeros(size(I)); mask(imageSize/4:3*imageSize/4,imageSize/4:3*imageSize/4)=1; % create toy mask
subplot(1,2,2); imshow(mask,[]); title('mask');
textureFeatures = averageChannelAbsInMask(Qu,mask,complexType,harmonicsVector,pyramid,cropSupport)

